Learn R Programming

assist (version 3.1.3)

summary.nnr: Object Summaries

Description

Summarize a nnr object

Usage

# S3 method for nnr
summary(object, ...)

Arguments

object

a fitted nnr object.

unused argument

Details

This is a method for the function summary for objects inheriting from class nnr. See summary for the general behavior of this function.

See Also

nnr, print.nnr