summary.snr: Object Summaries
Description
Summarize a snr object
Usage
# S3 method for snr
summary(object, ...)
Details
This is a method for the function summary for objects inheriting from class
snr. See summary for the general behavior of this function.