powered by
Provides a synopsis of a ssr object and perform tests.
ssr
# S3 method for ssr summary(object, ...)
a fitted ssr object.
unused option.
This is a method for the function summary for objects inheriting from class ssr.
summary
ssr, print.ssr
print.ssr