summary.nnr: Object Summaries
Description
Summarize a nnr object
Usage
# S3 method for nnr
summary(object, ...)
Details
This is a method for the function summary for objects inheriting from class
nnr. See summary for the general behavior of this function.